==> dinolib-0.9.1.tar.gz: dinolib-0.9.1/lib/dino_browser.php <==
<?php {
  /*
   * $Id: dino_browser.php,v 1.16 2003/03/14 17:41:40 tumf Exp $
   * Copyright (c) 2002-2003 Dino Co.,Ltd.
   */

  define('BROWSER_PRIFLE_DIR','browser/profile/');
  /**   
   * 桼Ƚ̽
   * 
   * ϼ2
   * - 桼Ƚ̤ڥåݻ롣
   * - IPemailɥ쥹ݻ
   * 
   * Ȥ
   *  case1: i-modeɤˤȤФ;
   *  $browser = new Dino_browser;
   *  if($browser->terminal == "docomo"){
   *        header_abs_location("/i/");
   *  }
   *  case2: ΰۤʤ룲β
   *  $browser = new Dino_Browser;
   *  $info = $browser->get_display_info())
   *  if(info["width"]>=120){
   *        $image = "big";
   *   }else{
   *        $image = "small";
   *   }
   *
   *
   * 2002-07-04EZΤߺǿΥǡ˹  
   * ˡΥǡϡBROWSER_PRIFLE_DIR/*.inc.phpɲäƤ
   *
   * @package Dino_Browser
   * @author tumf
   * @access public
   */
  class Dino_Browser {
    var $terminal;      // ü̾
    var $agent;		// HTTP_USER_AGENT


    /**
     * 󥹥ȥ饯
     * 
     * ֥饦μ
     * 
     * @access public
     */
    function Dino_Browser() {
      $this->agent  = getenv("HTTP_USER_AGENT");
      $this->terminal = $this->get_terminal_type();
    }
   
  

    /**
     * ֥饦μ
     *
     * browsecap ȤǺ
     * IE,NetScape,Mozilla,wap,and maybe moreꤿ 
     * 
     * @access public
     */
    function get_browser_type() {

      $agent = $this->agent;

      // OperaüʤᡢȽꤹ
      if (ereg("^.*(Opera)[ /]([0-9]+.[0-9]*).*$", $agent, $op_regs)) {
	//Operaפޤ -> OperaǤ
	$opera = array("type" => $op_regs[1],
		       "ver"  => $op_regs[2]);
	return $opera;
      }
      //MozillaפޤफɤȽ(IENetscapeMozillaϤޤ)
      else if (ereg("^.*(Mozilla)/([0-9]+.[0-9]*).*$", $agent, $m_regs)) {
	
	if(ereg("^.*compatible.*MSIE ([0-9]+.[0-9]*).*$",$agent, $ie_regs)) {
	  //compatibleסMSIEפޤ -> IE Ǥ
	  $ie = array("type" => "Internet Explorer",
		      "ver"  => $ie_regs[1]);
	  return $ie;
	}
	else if (!ereg("^.*Gecko.*$", $agent)) {
	  //ʳǡGeckoפޤޤʤ -> Netscape Navigator Ǥ
	  $nesc_navi = array("type" => "Netscape Navigator",
			     "ver"  => $m_regs[2]);
	  return $nesc_navi;
	}
	else if (ereg("^.*(Netscape6?)/([0-9]+.[0-9]*).*$", $agent, $n_regs)){
	  //ʳǡNetscapeפޤ -> Netscape Ǥ
	  $netscape = array("type" => $n_regs[1],
			    "ver"  => $n_regs[2]);
	  return $netscape;
	}
	else {
	  //ʳ -> Mozilla Ǥ
	  $mozilla = array("type" => $m_regs[1],
			   "ver"  => $m_regs[2]);
	  return $mozilla;
	}
      }
      else { //Mozillaפޤޤʤ
	return false;  //ʥ֥饦Τ
      }
    }

    /**
     * äΥꥢȽ 
     *
     * @access public
     *
     */
    function get_terminal_type(){
      $agent = $this->agent; //useragent
      $accept = getenv("HTTP_ACCEPT");
      $jphone = getenv("HTTP_X_JPHONE_MSNAME");

      if ( isset($jphone) && preg_match("/^J-PHONE/",$agent ) ) {
	return "jphone";  //J-Phone

      } elseif ( ereg("UP\.Browser",$agent) && ereg("hdml",$accept) ) {
	return "ez";  //ez

      } elseif ( preg_match("/^DoCoMo/",$agent) ) {
	return "docomo";  //DoCoMo

      } elseif ( preg_match("/^PDXGW/", $agent) ){	
	return "pdx";  //H" 

      } else {
	return "etc";  //pc and unknown 
      }
    }


    /**
     * üȽ
     *
     * @access public
     * @return boolen üʤtrue, Or false
     */
    function is_handy(){
      if ( $this->get_terminal_type() != "etc" ) {
	return true;
      }
    }

    /**
     * üȽ
     * 
     * is_handy() Ʊ̣
     *
     * @access public
     * @return boolen üʤtrue, Or false
     */
    function is_mobileagent(){
      return $this->is_handy();
    }

    /**
     * üɽǽϾ
     *
     * *ʲΣ֤ޤ
     * 1,color  顼ξ:1 ξ:0
     * 2,depth  ԥ뤢Υӥåȿ2Ĵ1
     * 3,width  ̤βԥ
     * 4,height ̤νĥԥ
     */
    function get_display_info(){
      $term = $this->terminal;
 
      if ( $term == "jphone" ){      //J-Phone
	$jcolor = getenv("HTTP_X_JPHONE_COLOR"); 
	$jsize  = getenv("HTTP_X_JPHONE_DISPLAY");

	list( $disp["width"], $disp["height"] ) = split( "\*", $jsize );
	if (substr($jcolor, 0, 1) == "C") {
	  $disp["color"]  = 1;
	  $disp["depth"]  = substr($jcolor, 1, strlen($jcolor)-1);
	} else {
	  $disp["color"]  = 0;  //
	  $disp["depth"]  = 1;  //ԥ뤢Υӥåȿ2Ĵ1
	}

      } elseif ( $term == "ez" ) {    //au
      
	$ez_size  = getenv("HTTP_X_UP_DEVCAP_SCREENPIXELS"); //size

	list( $disp["width"], $disp["height"] ) = split( ",", $ez_size );
	
	$disp["color"]  = getenv("HTTP_X_UP_DEVCAP_ISCOLOR"); //0:mono 1:color
	$disp["depth"]  = getenv("HTTP_X_UP_DEVCAP_SCREENDEPTH");  //

      } elseif ( $term == "docomo" ) { //DoCoMo 
	require_once(BROWSER_PROFILE_DIR."i_display.inc"); //ɽǽϥǡ
	$imode = $this->get_basic_info();

	list( $disp["width"], $disp["height"], $disp["depth"] ) = $imode_display[$imode["name"]];
	$disp["color"]  = ( $disp["depth"] >= 8 ); //8ʾǥ顼

      } else {
	return false;
      }
      return $disp;
    }

    /**
     * ü[]ɽǽ
     *
     *         ̣           value                for
     * smd     sound level    int                  /jphoneΤ
     * smaf    type of SMAF                        /jphoneΤ 
     * qcelp   ե   qcelp,none           /ezΤ
     * chord   ²         int                  /ez,docomo
     * type               i/ĥ ez/int      /ez,docomo
     */
    function get_sound_spec(){
      if ( $this->terminal == "jphone" ) {
	//case:J-Phone  
	$chaku = array("smd"=>getenv("HTTP_X_JPHONE_SOUND"),////ɥ٥
		       "smaf"=>getenv("HTTP_X_JPHONE_SMAF"));//SMAFΥ׼

      } elseif ( $this->terminal == "ez" ) {
	//case:ez  chord=²type=(0=none/1=mono/2=C-MIDI/3=SMAF)
	require_once(BROWSER_PROFILE_DIR."ez_chaku.inc"); //ǡ
	require_once(BROWSER_PROFILE_DIR."ez_qcelp.inc"); //Qcelpбüꥹ

	$info = $this->get_basic_info();
	$chaku["qcelp"] = "none";
	if(array_search($info["name"],$qcelp_list)){
	  //ͤưʪʤɥץ󥰲Ĥ餹ȤǤ뵻
	  $chaku["qcelp"] = "qcelp";
	}

	list($chaku["chord"],$chaku["type"]) = $chaku_list[$info["code"]];

      } elseif ( $this->terminal == "docomo" ) {
	//case:docmo //chord=²,type=(mld,rng)
	require_once(BROWSER_PROFILE_DIR."i_chaku.inc"); //ǡ

	$info = $this->get_basic_info();
	list($chaku["chord"],$chaku["type"])= $chaku_list[$info["name"]];

      } else {
	return false;
      }
      return $chaku;
    }

    /**
     * üδܾ
     *
     *
     * type  docomo=i,jphone=j,ez=e
     * name  ̾
     * code  拾     
     * ver   С     int
     * wap   wapС  int               /ez
     * mail  atmail         atmail,regular    /ez
     * subid unique id                        /ez
     * sub   cache          kilo              /docomo
     */
    function get_basic_info(){
      if($this->terminal == "jphone" ){
	//J-Phone by vodafone
	require_once(BROWSER_PROFILE_DIR."j_name.inc"); //̾ǡ

	$jphone = getenv("HTTP_X_JPHONE_MSNAME"); //̾(+version)
	$arrAgent = split("/",$this->agent);
	$info["type"] = "j"; // jphone	  
	$info["name"] = ($jphone_name[$jphone] == "")?$jphone:$jphone_name[$jphone];   //̾
	$info["code"] = $jphone;       //
	$info["ver"]  = $arrAgent[1];  //browserΥС

      } elseif ( $this->terminal == "ez" ) {
	//au by KDDI
	require_once(BROWSER_PROFILE_DIR."ez_name.inc"); //̾ǡ

	$piece = split("/",$this->agent);
	if( ereg("^KDDI\-([^ ]+)",$piece[0],$regarr) ){
	  $name = $regarr[1];
	  $info["ver"] = $piece[2];  //UP.Browser
	  $info["wap"] = "2";       //WAP2.0б
	} else {
	  $piece2 = split(" ",$piece[1]);
	  list( $info["ver"], $name ) = split("-",$piece2[0]); 
	  $info["wap"] = "1";      //WAP2.0"̤"б
	}

	$info["type"]   = "e";   //ezweb
	$info["code"]   = $name; // 
	$info["name"]  =($ezweb_name[$name] == "")?$name:$ezweb_name[$name];
	$info["subid"]  = getenv("HTTP_X_UP_SUBNO");   //unique id 
	$info["mail"] =  "regular";

	list($pre, $dev) = explode("_",$info["subid"]);
	if( ereg("[amt][a-z]\.ezweb\.ne\.jp",$dev) ){
	  $info["mail"] = "AtMail";
	}


     } elseif ($this->terminal == "docomo" ) {
	//NTT DoCoMo
       require_once(BROWSER_PROFILE_DIR."i_ver.inc");

	list( $docomo, $ver, $name, $sub) = split( "/", $this->agent );

	$info["type"]   = "i";   //DoCoMo
	$info["name"]   = $name;
	$info["sub"]    = ($sub == "")?"c5":$sub;  //cache :default 5k
	$info["ver"]    = $imode_ver[$name];

      } else {
	return false;
      }
      return $info;
    }


    /**
     * ʸɤ
     *
     * code  i-modeʸ
     * EZwebξG/W餷ѴƤ롣
     * alt false ʤ鼫ưǤ줿
     *
     * i-mode γʸˤĤ
     *   http://www.nttdocomo.co.jp/p_s/imode/tag/emoji/list.html
     * 򻲾ȤΤ
     *
     *  i-mode δܳʸ
     * i-mode ȸƤФƤ뵡176γʸȤ
     * EZwebǤ⤽ѴƤ롣
     *
     *  i-mode γĥʸΰ
     * HTML4.0бܹ Ĥޤ  504iʹߤͭ
     * 
     * 76γʸɲäƤ
     * EZwebǤ̵ߤ
     *   
     * @param code i-modeʸ(SJIS)
     * @param alt  ʸɽǤʤऱɽʸ
     * @access public
     */
    function emoji($code,$alt=false){

      // $codeγʸפȽꤹ
      $emoji_type=$this->get_emoji_type($code);

      //ܳʸ docomo or ez ֤
      if($emoji_type==1){
	if($this->is_cap("i-mode_emoji")){
	  return 
	    mb_convert_encoding($code,"eucJP-win","sjis-win");
	}
      }
      // ĥʸξ
      if($emoji_type==2){
	if($this->is_cap("i-mode_emoji2")){
	  return 
	    mb_convert_encoding($code,"eucJP-win","sjis-win");
	}
      }

      if(strlen($alt)>0){
	return $alt;
      }
      return " ";
    }

    /**
     * ʸɤ ĥʸɤȽ
     *
     * 
     * @return integer 1=basic / 2=extended / 0=unknown
     * @access public
     */
    function get_emoji_type($code){
      if(("\xf8\x9f"<=$code && $code <="\xf8\xfc")
	 ||("\xf9\x40"<=$code && $code<="\xf9\x49")
	 ||("\xf9\x72"<=$code && $code<="\xf9\xaf")
	 ||("\xf9\x50"<=$code && $code<="\xf9\x5e")){
	return 1;
      }

      if(("\xf9\xb1"<=$code && $code <="\xf9\xfc")){
	return 2;
      }

      return 0;
    }

    /**
     * ֥饦ǽȽ
     *
     * $capname
     * "i-mode_html_4.0"  i⡼бHTML4.0 
     * "i-mode_emoji"     i⡼ ܳʸб
     * "i-mode_emoji2"    i⡼ ĥʸб
     *
     *
     * @return boolean true capable ,or false
     * @access public
     */
    function is_cap($capname){
      $ttype=$this->get_terminal_type();

      // i⡼бHTML4.0 
      if($capname == "i-mode_html_4.0"){
	if(preg_match("{^DoCoMo/1\.0/(D|F|N|SO|P)504iS?/.*$}",$this->agent)
	   ||preg_match("{^DoCoMo/1\.0/(D|F|N|P)251iS?/.*$}",$this->agent)
	   ||preg_match("{^DoCoMo/1\.0/F671iS/.*$}",$this->agent)
	   ||preg_match("{^DoCoMo/1\.0/(F|SO)212i/.*$}",$this->agent)
	   ||preg_match("{^DoCoMo/2\.0 (N|F)2051.*$}",$this->agent)
	   ||preg_match("{^DoCoMo/2\.0 P2102.*$}",$this->agent)
	   ){
	  return true;
	}
	return false;
      }

      // i⡼ɴܳʸ
      if($capname == "i-mode_emoji"){
	if($ttype == "docomo" || $ttype == "ez"){
	  return true;
	}
	return false;
      }

      // i⡼ɳĥʸ
      if($capname == "i-mode_emoji2"){
	return $this->is_cap("i-mode_html_4.0"); //ɤ
      }


    }
  }
  
}?>

==> dinolib-0.9.2.tar.gz: dinolib-0.9.2/lib/dino_browser.php <==
<?php {
  /*
   * $Id: dino_browser.php,v 1.18 2003/04/01 10:49:22 nishina Exp $
   * Copyright (c) 2002-2003 Dino Co.,Ltd.
   */

  define('BROWSER_PRIFLE_DIR','browser/profile/');
  /**   
   * 桼Ƚ̽
   * 
   * ϼ2
   * - 桼Ƚ̤ڥåݻ롣
   * - IPemailɥ쥹ݻ
   * 
   * Ȥ
   *  case1: i-modeɤˤȤФ;
   *  $browser = new Dino_browser;
   *  if($browser->terminal == "docomo"){
   *        header_abs_location("/i/");
   *  }
   *  case2: ΰۤʤ룲β
   *  $browser = new Dino_Browser;
   *  $info = $browser->get_display_info())
   *  if(info["width"]>=120){
   *        $image = "big";
   *   }else{
   *        $image = "small";
   *   }
   *
   *
   * 2002-07-04EZΤߺǿΥǡ˹  
   * ˡΥǡϡBROWSER_PRIFLE_DIR/*.inc.phpɲäƤ
   *
   * @package Dino_Browser
   * @author tumf
   * @access public
   */
  class Dino_Browser {
    var $terminal;      // ü̾
    var $agent;		// HTTP_USER_AGENT


    /**
     * 󥹥ȥ饯
     * 
     * ֥饦μ
     * 
     * @access public
     */
    function Dino_Browser() {
      $this->agent  = getenv("HTTP_USER_AGENT");
      $this->terminal = $this->get_terminal_type();
    }

    /**
     * ֥饦μ
     *
     * browsecap ȤǺ
     * IE,NetScape,Mozilla,wap,and maybe moreꤿ 
     * 
     * @access public
     */
    function get_browser_type() {

      $agent = $this->agent;

      // OperaüʤᡢȽꤹ
      if (ereg("^.*(Opera)[ /]([0-9]+.[0-9]*).*$", $agent, $op_regs)) {
	//Operaפޤ -> OperaǤ
	$opera = array("type" => $op_regs[1],
		       "ver"  => $op_regs[2]);
	return $opera;
      }
      //MozillaפޤफɤȽ(IENetscapeMozillaϤޤ)
      else if (ereg("^.*(Mozilla)/([0-9]+.[0-9]*).*$", $agent, $m_regs)) {
	
	if(ereg("^.*compatible.*MSIE ([0-9]+.[0-9]*).*$",$agent, $ie_regs)) {
	  //compatibleסMSIEפޤ -> IE Ǥ
	  $ie = array("type" => "Internet Explorer",
		      "ver"  => $ie_regs[1]);
	  return $ie;
	}
	else if (!ereg("^.*Gecko.*$", $agent)) {
	  //ʳǡGeckoפޤޤʤ -> Netscape Navigator Ǥ
	  $nesc_navi = array("type" => "Netscape Navigator",
			     "ver"  => $m_regs[2]);
	  return $nesc_navi;
	}
	else if (ereg("^.*(Netscape6?)/([0-9]+.[0-9]*).*$", $agent, $n_regs)){
	  //ʳǡNetscapeפޤ -> Netscape Ǥ
	  $netscape = array("type" => $n_regs[1],
			    "ver"  => $n_regs[2]);
	  return $netscape;
	}
	else {
	  //ʳ -> Mozilla Ǥ
	  $mozilla = array("type" => $m_regs[1],
			   "ver"  => $m_regs[2]);
	  return $mozilla;
	}
      }
      else { //Mozillaפޤޤʤ
	return false;  //ʥ֥饦Τ
      }
    }

    /**
     * äΥꥢȽ 
     *
     * @access public
     *
     */
    function get_terminal_type() {
      $agent = $this->agent; //useragent
      $accept = getenv("HTTP_ACCEPT");
      $jphone = getenv("HTTP_X_JPHONE_MSNAME");

      if ( isset($jphone) && preg_match("/^J-PHONE/",$agent ) ) {
	return "jphone";  //J-Phone

      } elseif ( ereg("UP\.Browser",$agent) && ereg("hdml",$accept) ) {
	return "ez";  //ez

      } elseif ( preg_match("/^DoCoMo/",$agent) ) {
	return "docomo";  //DoCoMo

      } elseif ( preg_match("/^PDXGW/", $agent) ){	
	return "pdx";  //H" 

      } else {
	return "etc";  //pc and unknown 
      }
    }

    /**
     * post methodѲǽȽ
     *
     * @access public
     * @return boolen Ѳǽʤtrue, Or false
     */    
    function is_available_post_method() {
      if (Dino_Browser::get_terminal_type() == "jphone") {
	return false;
      }else{
	return true;
      }
    }

    /**
     * üȽ
     *
     * @access public
     * @return boolen üʤtrue, Or false
     */
    function is_handy(){
      if ( $this->get_terminal_type() != "etc" ) {
	return true;
      }
    }

    /**
     * javascriptѲǽȽ
     *
     * @access public
     * @return boolen Ѳǽʤtrue, Or false
     */    
    function is_available_js() {
      if ( Dino_Browser::get_terminal_type() == "etc" ) {
	return true;
      }else{
	return false;
      }
    }

    /**
     * üȽ
     * 
     * is_handy() Ʊ̣
     *
     * @access public
     * @return boolen üʤtrue, Or false
     */
    function is_mobileagent(){
      return $this->is_handy();
    }

    /**
     * üɽǽϾ
     *
     * *ʲΣ֤ޤ
     * 1,color  顼ξ:1 ξ:0
     * 2,depth  ԥ뤢Υӥåȿ2Ĵ1
     * 3,width  ̤βԥ
     * 4,height ̤νĥԥ
     */
    function get_display_info(){
      $term = $this->terminal;
 
      if ( $term == "jphone" ){      //J-Phone
	$jcolor = getenv("HTTP_X_JPHONE_COLOR"); 
	$jsize  = getenv("HTTP_X_JPHONE_DISPLAY");

	list( $disp["width"], $disp["height"] ) = split( "\*", $jsize );
	if (substr($jcolor, 0, 1) == "C") {
	  $disp["color"]  = 1;
	  $disp["depth"]  = substr($jcolor, 1, strlen($jcolor)-1);
	} else {
	  $disp["color"]  = 0;  //
	  $disp["depth"]  = 1;  //ԥ뤢Υӥåȿ2Ĵ1
	}

      } elseif ( $term == "ez" ) {    //au
      
	$ez_size  = getenv("HTTP_X_UP_DEVCAP_SCREENPIXELS"); //size

	list( $disp["width"], $disp["height"] ) = split( ",", $ez_size );
	
	$disp["color"]  = getenv("HTTP_X_UP_DEVCAP_ISCOLOR"); //0:mono 1:color
	$disp["depth"]  = getenv("HTTP_X_UP_DEVCAP_SCREENDEPTH");  //

      } elseif ( $term == "docomo" ) { //DoCoMo 
	require_once(BROWSER_PROFILE_DIR."i_display.inc"); //ɽǽϥǡ
	$imode = $this->get_basic_info();

	list( $disp["width"], $disp["height"], $disp["depth"] ) = $imode_display[$imode["name"]];
	$disp["color"]  = ( $disp["depth"] >= 8 ); //8ʾǥ顼

      } else {
	return false;
      }
      return $disp;
    }

    /**
     * ü[]ɽǽ
     *
     *         ̣           value                for
     * smd     sound level    int                  /jphoneΤ
     * smaf    type of SMAF                        /jphoneΤ 
     * qcelp   ե   qcelp,none           /ezΤ
     * chord   ²         int                  /ez,docomo
     * type               i/ĥ ez/int      /ez,docomo
     */
    function get_sound_spec(){
      if ( $this->terminal == "jphone" ) {
	//case:J-Phone  
	$chaku = array("smd"=>getenv("HTTP_X_JPHONE_SOUND"),////ɥ٥
		       "smaf"=>getenv("HTTP_X_JPHONE_SMAF"));//SMAFΥ׼

      } elseif ( $this->terminal == "ez" ) {
	//case:ez  chord=²type=(0=none/1=mono/2=C-MIDI/3=SMAF)
	require_once(BROWSER_PROFILE_DIR."ez_chaku.inc"); //ǡ
	require_once(BROWSER_PROFILE_DIR."ez_qcelp.inc"); //Qcelpбüꥹ

	$info = $this->get_basic_info();
	$chaku["qcelp"] = "none";
	if(array_search($info["name"],$qcelp_list)){
	  //ͤưʪʤɥץ󥰲Ĥ餹ȤǤ뵻
	  $chaku["qcelp"] = "qcelp";
	}

	list($chaku["chord"],$chaku["type"]) = $chaku_list[$info["code"]];

      } elseif ( $this->terminal == "docomo" ) {
	//case:docmo //chord=²,type=(mld,rng)
	require_once(BROWSER_PROFILE_DIR."i_chaku.inc"); //ǡ

	$info = $this->get_basic_info();
	list($chaku["chord"],$chaku["type"])= $chaku_list[$info["name"]];

      } else {
	return false;
      }
      return $chaku;
    }

    /**
     * üδܾ
     *
     *
     * type  docomo=i,jphone=j,ez=e
     * name  ̾
     * code  拾     
     * ver   С     int
     * wap   wapС  int               /ez
     * mail  atmail         atmail,regular    /ez
     * subid unique id                        /ez
     * sub   cache          kilo              /docomo
     */
    function get_basic_info(){
      if($this->terminal == "jphone" ){
	//J-Phone by vodafone
	require_once(BROWSER_PROFILE_DIR."j_name.inc"); //̾ǡ

	$jphone = getenv("HTTP_X_JPHONE_MSNAME"); //̾(+version)
	$arrAgent = split("/",$this->agent);
	$info["type"] = "j"; // jphone	  
	$info["name"] = ($jphone_name[$jphone] == "")?$jphone:$jphone_name[$jphone];   //̾
	$info["code"] = $jphone;       //
	$info["ver"]  = $arrAgent[1];  //browserΥС

      } elseif ( $this->terminal == "ez" ) {
	//au by KDDI
	require_once(BROWSER_PROFILE_DIR."ez_name.inc"); //̾ǡ

	$piece = split("/",$this->agent);
	if( ereg("^KDDI\-([^ ]+)",$piece[0],$regarr) ){
	  $name = $regarr[1];
	  $info["ver"] = $piece[2];  //UP.Browser
	  $info["wap"] = "2";       //WAP2.0б
	} else {
	  $piece2 = split(" ",$piece[1]);
	  list( $info["ver"], $name ) = split("-",$piece2[0]); 
	  $info["wap"] = "1";      //WAP2.0"̤"б
	}

	$info["type"]   = "e";   //ezweb
	$info["code"]   = $name; // 
	$info["name"]  =($ezweb_name[$name] == "")?$name:$ezweb_name[$name];
	$info["subid"]  = getenv("HTTP_X_UP_SUBNO");   //unique id 
	$info["mail"] =  "regular";

	list($pre, $dev) = explode("_",$info["subid"]);
	if( ereg("[amt][a-z]\.ezweb\.ne\.jp",$dev) ){
	  $info["mail"] = "AtMail";
	}


     } elseif ($this->terminal == "docomo" ) {
	//NTT DoCoMo
       require_once(BROWSER_PROFILE_DIR."i_ver.inc");

	list( $docomo, $ver, $name, $sub) = split( "/", $this->agent );

	$info["type"]   = "i";   //DoCoMo
	$info["name"]   = $name;
	$info["sub"]    = ($sub == "")?"c5":$sub;  //cache :default 5k
	$info["ver"]    = $imode_ver[$name];

      } else {
	return false;
      }
      return $info;
    }


    /**
     * ʸɤ
     *
     * code  i-modeʸ
     * EZwebξG/W餷ѴƤ롣
     * alt false ʤ鼫ưǤ줿
     *
     * i-mode γʸˤĤ
     *   http://www.nttdocomo.co.jp/p_s/imode/tag/emoji/list.html
     * 򻲾ȤΤ
     *
     *  i-mode δܳʸ
     * i-mode ȸƤФƤ뵡176γʸȤ
     * EZwebǤ⤽ѴƤ롣
     *
     *  i-mode γĥʸΰ
     * HTML4.0бܹ Ĥޤ  504iʹߤͭ
     * 
     * 76γʸɲäƤ
     * EZwebǤ̵ߤ
     *   
     * @param code i-modeʸ(SJIS)
     * @param alt  ʸɽǤʤऱɽʸ
     * @access public
     */
    function emoji($code,$alt=false){

      // $codeγʸפȽꤹ
      $emoji_type=$this->get_emoji_type($code);

      //ܳʸ docomo or ez ֤
      if($emoji_type==1){
	if($this->is_cap("i-mode_emoji")){
	  return 
	    mb_convert_encoding($code,"eucJP-win","sjis-win");
	}
      }
      // ĥʸξ
      if($emoji_type==2){
	if($this->is_cap("i-mode_emoji2")){
	  return 
	    mb_convert_encoding($code,"eucJP-win","sjis-win");
	}
      }

      if(strlen($alt)>0){
	return $alt;
      }
      return " ";
    }

    /**
     * ʸɤ ĥʸɤȽ
     *
     * 
     * @return integer 1=basic / 2=extended / 0=unknown
     * @access public
     */
    function get_emoji_type($code){
      if(("\xf8\x9f"<=$code && $code <="\xf8\xfc")
	 ||("\xf9\x40"<=$code && $code<="\xf9\x49")
	 ||("\xf9\x72"<=$code && $code<="\xf9\xaf")
	 ||("\xf9\x50"<=$code && $code<="\xf9\x5e")){
	return 1;
      }

      if(("\xf9\xb1"<=$code && $code <="\xf9\xfc")){
	return 2;
      }

      return 0;
    }

    /**
     * ֥饦ǽȽ
     *
     * $capname
     * "i-mode_html_4.0"  i⡼бHTML4.0 
     * "i-mode_emoji"     i⡼ ܳʸб
     * "i-mode_emoji2"    i⡼ ĥʸб
     *
     *
     * @return boolean true capable ,or false
     * @access public
     */
    function is_cap($capname){
      $ttype=$this->get_terminal_type();

      // i⡼бHTML4.0 
      if($capname == "i-mode_html_4.0"){
	if(preg_match("{^DoCoMo/1\.0/(D|F|N|SO|P)504iS?/.*$}",$this->agent)
	   ||preg_match("{^DoCoMo/1\.0/(D|F|N|P)251iS?/.*$}",$this->agent)
	   ||preg_match("{^DoCoMo/1\.0/F671iS/.*$}",$this->agent)
	   ||preg_match("{^DoCoMo/1\.0/(F|SO)212i/.*$}",$this->agent)
	   ||preg_match("{^DoCoMo/2\.0 (N|F)2051.*$}",$this->agent)
	   ||preg_match("{^DoCoMo/2\.0 P2102.*$}",$this->agent)
	   ){
	  return true;
	}
	return false;
      }

      // i⡼ɴܳʸ
      if($capname == "i-mode_emoji"){
	if($ttype == "docomo" || $ttype == "ez"){
	  return true;
	}
	return false;
      }

      // i⡼ɳĥʸ
      if($capname == "i-mode_emoji2"){
	return $this->is_cap("i-mode_html_4.0"); //ɤ
      }


    }
  }
  
}?>
